Developer Guide
===============

| The Grayskull project is under active development.
| We courage community members to contribute to this development.
| The Grayskull source code can be found `here <https://github.com/conda-incubator/grayskull/tree/main/grayskull>`_.